import os

import boto3
import psycopg2


def get_secret(name):
    session = boto3.session.Session()
    client = session.client(service_name="ssm", region_name="ap-northeast-1")

    res = client.get_parameter(Name=name, WithDecryption=True)
    return res['Parameter']['Value']


def get_connection():
    host = os.environ.get('DB_HOST')
    user = get_secret('/batch/DB_USERNAME')
    password = get_secret('/batch/DB_PASSWORD')
    database = "dbname"
    port = 5432
    db_url = f"postgresql://{user}:{password}@{host}:{port}/{database}"

    return psycopg2.connect(db_url)


def handler(event, context):
    with get_connection() as conn:
        with conn.cursor() as cur:
            cur.execute("""DELETE
FROM history
WHERE insert_timestamp < date_trunc('day', CURRENT_TIMESTAMP) + interval '-90 day';
            """)
